<?php

class dbClass extends PDO {
		
		public $paxtool_db; 	
		public $st_db;		
		public $bms_db;
		
		public $db_dsn;
		public $db_user;
		public $db_password;
		
		var $error_message;			//  If an error occurs in data retrieval this will contain the error message.
		
		
		function __construct( $db_dsn, $db_user, $db_password ) {
			
			//  Call the constructor for the extended class.
			//
			parent::__construct( $db_dsn, $db_user, $db_password );
			
			//  Set up default values for the names of the databases. 
			// 	
 			$this->paxtool_db 	= $GLOBALS[ 'cfg_paxtool_db' ];
 			$this->st_db		= $GLOBALS[ 'cfg_salestool_db' ];
 			$this->bms_db		= $GLOBALS[ 'cfg_bms_db' ];
			
 			
		}
		
		
		
		
		function isValidKey( $api_key="" ) {
			
			$sql_query = "
					
					SELECT		COUNT(*)			AS api_matches
					
					FROM		webapi_users
						AS		users
					
					WHERE		users.api_key = :api_key;
					
					";
			
			$sql = $this->prepare( $sql_query );
			$variables = array( ':api_key'=>$api_key );
			$sql->execute( $variables );
			
			$is_valid_key = ( (int)$sql->fetchColumn() == 1 );
			
			return( $is_valid_key );
		}
		
		
		
		
		function getVesselList( ) {
			
			$sql_query = "
					
					SELECT 		ter.ter_schiff		AS vessel_name
					
					FROM		`{$this->paxtool_db}`.pax_si_termine
						AS		ter
						
					LEFT JOIN	`{$this->st_db}`.st_vessels
						AS		vessels
						ON		vessels.ves_name = ter.ter_schiff
					
					WHERE 		ter.ter_von > NOW()
						AND		vessels.ves_fleet = 'Siren Fleet'
					
					GROUP BY	vessel_name
					
					ORDER BY	vessel_name;

					";
			
			$sql = $this->prepare( $sql_query );
			$sql->execute();
			
			$a_vessels = $sql->fetchAll( PDO::FETCH_OBJ );
			
			return( $a_vessels );		
			
		}
		
		
		
		function getLastTripDate( $vessel="" ) {
			
			$vessel_filter = ( $vessel == "" ) ? "1" : "ter.ter_schiff = :vessel";
			
			$sql_query = "
					
					SELECT		ter.ter_von			AS trip_date
					
					FROM		{$this->paxtool_db}.pax_si_termine
						AS		ter
						
					WHERE		{$vessel_filter}
			
					ORDER BY	trip_date DESC
					
					LIMIT 		1;
					
					";
			
			$sql = $this->prepare( $sql_query );
			$sql->execute( array( ':vessel'=>$vessel ));
			
			$last_trip_date = $sql->fetchColumn();
			
			return( $last_trip_date );			
		}
		
		
		
		function getVesselTrips( $vessel, $start_date, $end_date, $currency="EUR" ) { 
			
			$vessel_filter = ( $vessel == "" ) ? ":vessel = :vessel" : "ter.ter_schiff = :vessel";
			
			$sql_query = "
					
					SELECT			ter.ter_schiff							AS vessel_name,
									ter.ter_code							AS trip_code,
									ter.ter_von								AS trip_start_date, 
									ter.ter_bis								AS trip_end_date, 
									DATEDIFF( ter.ter_bis, ter.ter_von ) 	AS trip_nights,
									roud.roud_name							AS trip_itinerary,
									ter.ter_preis_1_wert					AS trip_price_eur,
									
									( SELECT 		COUNT(*)
										FROM 		{$this->paxtool_db}.pax_si_belegung_details
											AS		beld
										JOIN		{$this->paxtool_db}.pax_si_belegung
											AS		bel
											ON		( bel.bel_ter_key = beld.beld_ter_key ) AND ( bel.bel_platz_nr = beld.beld_platz_nr )
										WHERE		beld.beld_ter_key = ter.ter_key
											AND		beld.beld_buchungsstatus = 'available'
											AND		bel.bel_kabine_status = 'public'
										)									AS spaces_available,
										
									terd.terd_bemerkung_public				AS trip_notes
					
					FROM			{$this->paxtool_db}.pax_si_termine
						AS			ter
						
					JOIN			{$this->paxtool_db}.pax_si_termine_details
						AS			terd
						ON			terd.terd_key = ter.ter_key
						
					JOIN			{$this->paxtool_db}.pax_si_routen_details
						AS			roud
						ON			roud.roud_key = ter.ter_rou_key
						
					JOIN			{$this->paxtool_db}.pax_si_routen
						AS			rou
						ON			rou.rou_key = ter.ter_rou_key
						
					WHERE			{$vessel_filter}
						AND			rou.rou_typ = 'I'
						AND			ter.ter_von >= :start_date
						AND			ter.ter_von <= :end_date
			
					ORDER BY		trip_start_date;
					
					";
			
			$sql = $this->prepare( $sql_query );
			
			$sql->execute( array( 	':vessel' => $vessel, 
									':start_date' => $start_date, 
									':end_date' => $end_date 
									));
			
			$a_trips = $sql->fetchAll( PDO::FETCH_OBJ );
			
			return( $a_trips );
		}
		
		
		
		function getTripAvailability( $trip_code ) {
			
			$sql_query = "
					
					SELECT		ter.ter_code							AS trip_code,
								ter.ter_schiff							AS trip_vessel,
								roud.roud_name							AS trip_itinerary,
								ter.ter_von								AS trip_start_date,
								ter.ter_bis								AS trip_end_date,
								DATEDIFF( ter.ter_bis, ter.ter_von )	AS trip_nights,
								ter.ter_preis_1_wert					AS trip_price_eur,
								
								( SELECT 		COUNT(*)
									FROM		{$this->paxtool_db}.pax_si_belegung_details
										AS		beld
									JOIN		{$this->paxtool_db}.pax_si_belegung
										AS		bel
										ON		bel.bel_ter_key = beld.beld_ter_key
											AND	bel.bel_platz_nr = beld.beld_platz_nr
											
									WHERE		beld.beld_ter_key = ter.ter_key
										AND		beld.beld_buchungsstatus = 'available'
										AND		bel.bel_kabine_status = 'public'
									)									AS trip_spaces_available,
									
								terd.terd_bemerkung_public				AS trip_notes
					
					FROM		{$this->paxtool_db}.pax_si_termine
						AS		ter
					
					JOIN			{$this->paxtool_db}.pax_si_termine_details
						AS			terd
						ON			terd.terd_key = ter.ter_key
						
					JOIN		{$this->paxtool_db}.pax_si_routen_details
						AS		roud
						ON		roud.roud_key = ter.ter_rou_key
						
					WHERE		ter.ter_code = :trip_code;
					";
			
			$sql_vars = array( ":trip_code" => $trip_code );
			
			$sql = $this->prepare( $sql_query );
			$sql->execute( $sql_vars );
			
			$a_results = $sql->fetchAll( PDO::FETCH_OBJ);
			
			$availability = ( count( $a_results ) == 0 ) 
				? FALSE
				: $a_results[ 0 ];
			
			return( $availability );
		}
		
	}
	?>