<?php

	include( 'class.db_class.inc.php');
	
	class ScubaTribeDBClass extends dbClass {
		

		
		/**
		 * Function		: __construct()
		 * 
		 */
		
		function __construct( $db_dsn, $db_user, $db_password ) {
			
			//  Call the constructor for the extended class. 
			//
			parent::__construct( $db_dsn, $db_user, $db_password ); 
			
		}
		
		
		
		function test() {
			var_dump( get_object_vars( $this ));
		}
		
		
		
		/**
		 * Function		: getActiveVessels()
		 * 
		 * Returns a list of active vessels along with the booking manager (BMS
		 * or Paxtool) that is used for each vessel.
		 *  
		 */
		function getActiveVesselInfo( $vessel = "" ) {
			
			//  If a vessel was specified, filter to include only that vessel.
			//
			$vessel_filter = ( $vessel != "" ) 
				? "ves.ves_name = '{$vessel}'"
				: "1";
			
			//  Create the SQL query.
			//
			$sql_query = "

				SELECT		ves.ves_name				AS name,
							ves.ves_fleet				AS fleet,
							ves.ves_booking_manager		AS booking_manager
							
				FROM		`{$this->st_db}`.st_vessels
					AS		ves
					
				WHERE		ves.ves_active
					AND		{$vessel_filter}
				
				ORDER BY	ves.ves_name
			
				";
			
			//  Try to prepare and execute the query, catching any 
			//  error that is generated. 
			// 	
			try {
				$sql = $this->prepare( $sql_query );
				$sql->execute();

				$a_vessels = array();
			
 				while( $vessel = $sql->fetchObject()) {
 					$a_vessels[ "{$vessel->name}" ] = $vessel;
				}
			}
			catch (PDOException $e ) {
				print $e->getMessage();
				$a_vessels = FALSE;
			}
			
			//  Return the results to the calling program.
			// 
			return( $a_vessels );
		}
		
		
		
		function getVesselList( $start_date, $end_date ) {
			
			$sql_query = "
	
				SELECT		ter.ter_schiff 			AS vessel
				
				FROM		`{$this->paxtool_db}`.pax_si_termine
					AS		ter
					
				JOIN		`{$this->paxtool_db}`.pax_si_routen
					AS		rou
					ON		rou.rou_key = ter.ter_rou_key
					
				WHERE		ter.ter_von <= :end_date
					AND		ter.ter_bis >= :start_date
					AND		rou.rou_typ = 'I'
					
				GROUP BY	vessel
				
				ORDER BY	vessel;
			
				";
			
			$sql = $this->prepare( $sql_query );
			
			$sql->bindParam( ":start_date", $start_date );
			$sql->bindParam( ":end_date", 	$end_date );
			
			$sql->execute();
			
			$a_vessels = array();
			
			while( $vessel = $sql->fetchColumn()) {
				$a_vessels[ "{$vessel}" ] = $vessel;
			}
			
			return( $a_vessels );
		}
		
		
		
		/**
		 * Function		: getVesselTripsFromBMS()
		 * 
		 * Returns a list of trips on a specified vessel operating between 
		 * two given dates.  Data is retrieved from the BMS database.
		 * 
		 * @param unknown_type $vessel
		 * @param unknown_type $start_date
		 * @param unknown_type $end_date
		 * @return multitype:
		 */
		function getVesselTripsFromBMS( $vessel, $start_date, $end_date ) {
			
			$sql_query = "

				SELECT			trip.code								AS trip_code, 
								trip.date_from							AS trip_start_date, 
								trip.date_to							AS trip_end_date,
								ttp.name								AS trip_itinerary,
								DATEDIFF( trip.date_to, trip.date_from)	AS trip_duration
								
				FROM			`{$this->bms_db}`.trip
					AS			trip
					
				JOIN			`{$this->bms_db}`.boat_profile
					AS			bp
					ON			bp.id = trip.boat_id
					
				JOIN			`{$this->bms_db}`.trip_template
					AS			tt
					ON			tt.id = trip.trip_template_id
					
				JOIN			`{$this->bms_db}`.trip_template_profile
					AS			ttp
					ON			ttp.trip_template_id = tt.id
					
				WHERE			bp.name = '{$vessel}'
					AND			trip.date_from <= '{$end_date}'
					AND			trip.date_to >= '{$start_date}'
					AND			tt.itinerary_type = 'ITINERARY'
					
				ORDER BY		trip_start_date, trip_end_date
			
				";

			$sql = $this->prepare( $sql_query );
			
			if ( !( $sql->execute() )) {
				$error_info = $sql->errorInfo();
				die( "ERROR ({$error_info[ 0 ]}/{$error_info[ 1 ]}): {$error_info[ 2 ]}" );
			}

			$a_results = $sql->fetchAll(PDO::FETCH_CLASS);
			
			return( $a_results );
		}
		
		
		
		/**
		 * Function 	: getVesselTripsFromPaxtool()
		 * 
		 * Returns a list of trips on a specified vessel operating between 
		 * two given dates.  Data is retrieved from the Paxtool database.
		 * 
		 * @param unknown_type $vessel
		 * @param unknown_type $start_date
		 * @param unknown_type $end_date
		 * @return multitype:
		 */
		
		function getVesselTripsFromPaxtool( $vessel, $start_date, $end_date ) {
			
			$sql_query = "
				
				SELECT			ter.ter_code							AS trip_code, 
								ter.ter_von								AS trip_start_date,
								ter.ter_bis								AS trip_end_date,
								roud.roud_name							AS trip_itinerary,
								DATEDIFF( ter.ter_bis, ter.ter_von ) 	AS trip_duration
				
				FROM			`{$this->paxtool_db}`.pax_si_termine
					AS			ter
					
				JOIN			`{$this->paxtool_db}`.pax_si_routen
					AS			rou
					ON			rou.rou_key = ter.ter_rou_key
					
				JOIN			`{$this->paxtool_db}`.pax_si_routen_details
					AS			roud
					ON			roud.roud_key = ter.ter_rou_key
					
				WHERE			ter.ter_schiff = :vessel
					AND			ter.ter_von <= :end_date
					AND			ter.ter_bis >= :start_date
					AND			rou.rou_typ = 'I'
					
				ORDER BY		trip_start_date, trip_end_date			
			
				";
			
			$sql = $this->prepare( $sql_query );
			
			$sql->bindParam( ':vessel', 	$vessel );
			$sql->bindParam( ':start_date', $start_date );
			$sql->bindParam( ':end_date', 	$end_date );
			
			$sql->execute();
			
			$a_results = $sql->fetchAll(PDO::FETCH_CLASS);
			
			return( $a_results );
		}
		
		
		
		
		/**
		 * Function		: getTripGuestsFromBMS()
		 * 
		 * @param unknown_type $trip_code
		 * @return multitype:
		 */
		function getTripGuestsFromBMS( $trip_code ) {
			
			$sql_query = "
			
				SELECT		DISTINCT booking_item_trip.id	AS booking_key,
							booking_customer.firstname		AS guest_fname, 
							booking_customer.lastname		AS guest_lname,
							customer.gender					AS guest_gender
							
				#  This is the main booking item table with links
				#  to supported tables. 
				#
				FROM		`{$this->bms_db}`.booking_item_trip
					AS		booking_item_trip
				
				#  Join the trip table so that we can get the trip code.
				#
				LEFT JOIN	`{$this->bms_db}`.trip
					AS		trip
					ON		trip.id = booking_item_trip.trip_id
				
				
				LEFT JOIN	`{$this->bms_db}`.booking_customer
					AS		booking_customer
					ON		booking_customer.id = booking_item_trip.booking_customer_id

					
				LEFT JOIN	`{$this->bms_db}`.customer
					AS		customer
					ON		customer.id = booking_customer.customer_id					
					
				#  Join the booking item table so that we can get the status
				#  of the booked guest.
				# 
				LEFT JOIN	`{$this->bms_db}`.booking
					AS		booking
					ON		booking.id = booking_item_trip.booking_id
										 
				WHERE		trip.code = '{$trip_code}'
					AND		booking.status = 'CONFIRMED'
					AND		booking_customer.lastname != ''
					
				ORDER BY	guest_lname, guest_fname
			
				";
			
			$sql = $this->prepare( $sql_query );
			
			if ( !( $sql->execute() )) {
				$error_info = $sql->errorInfo();
				die( "ERROR ({$error_info[ 0 ]}/{$error_info[ 1 ]}): {$error_info[ 2 ]}" );
			};
			
			$a_results = $sql->fetchAll( PDO::FETCH_CLASS );
			
			return( $a_results );			
		}
		
		
		/**
		 * Function		: getTripGuestsFromPaxtool()
		 * 
		 * @param unknown_type $trip_code
		 * @return multitype:
		 */
		function getTripGuestsFromPaxtool( $trip_code ) {
			
			//  Exclude guests who are in the following categories.
			//
			//	Removed 
			//
			$a_exclude_categories = array(
//								18,		// WWDAS Staff					
								23,		// Internal admin guests -- eg: single supplement, etc.
								);
			
			
			//  Build a comma delimited list of categories to exclude.
			//
			$exclude_list = "";
			$comma = "";
			
			foreach( $a_exclude_categories as $cat ) {
				$exclude_list .= "{$comma}{$cat}";
				$comma = ", ";
			}
			
			$sql_query = "
			
				SELECT			beld.beld_key						AS booking_key,
								kun.kun_vorname						AS guest_fname, 
								kun.kun_nachname					AS guest_lname,
								kun.kun_geschlecht					AS guest_gender
								
				FROM			`{$this->paxtool_db}`.pax_si_belegung_details
					AS			beld
					
				JOIN			`{$this->paxtool_db}`.pax_si_kunden
					AS			kun
					ON			kun.kun_key = beld.beld_kun_key
					
				JOIN			`{$this->paxtool_db}`.pax_si_termine
					AS			ter
					ON			ter.ter_key = beld.beld_ter_key
					
				WHERE			ter.ter_code = :trip_code
					AND			beld.beld_buchungsstatus = 'confirmed'
					AND			kun.kun_kategorie NOT IN ( {$exclude_list} )
					
				ORDER BY		guest_lname, guest_fname, beld.beld_platz_nr;
			
				";
			
			$sql = $this->prepare( $sql_query );
			
			$sql->bindParam( ":trip_code", $trip_code );
			
			$sql->execute();
			
			$a_results = $sql->fetchAll( PDO::FETCH_CLASS );
			
			return( $a_results );
		}
		
	}
	
	?>